@@ -1,10 +1,12 @@
 use std::str::FromStr;
 
 use clap::{crate_authors, crate_description, crate_version, ArgEnum, Parser};
+use strum::EnumIter;
 
 // TODO: rot13 & rotN
 // TODO: binary, octal
-#[derive(Debug, ArgEnum, Clone, PartialEq, Eq)]
+// TODO: utf16le, ucs2, ucs-2, latin1
+#[derive(Debug, ArgEnum, EnumIter, Clone, PartialEq, Eq)]
 pub enum Encoding {
     Raw,
     // Character encodings
@@ -36,6 +38,11 @@ pub enum Encoding {
     Base64Crypt,
     #[clap(name("base64:imap"))]
     Base64ImapMutf7,
+    // Base85
+    #[clap(name("base85"))]
+    Base85Rfc1924,
+    #[clap(name("ascii85"))]
+    Base85Ascii,
 }
 
 impl ToString for Encoding {
@@ -58,6 +65,9 @@ impl ToString for Encoding {
             Self::Base64StandardNoPadding => "base64|".into(),
             Self::Base64UrlSafe => "base64:url".into(),
             Self::Base64UrlSafeNoPadding => "base64:url|".into(),
+
+            Self::Base85Rfc1924 => "base85".into(),
+            Self::Base85Ascii => "ascii85".into(),
         }
     }
 }
@@ -87,6 +97,10 @@ impl FromStr for Encoding {
             "base64:standard|" => Ok(Self::Base64StandardNoPadding),
             "base64:url" => Ok(Self::Base64UrlSafe),
             "base64:url|" => Ok(Self::Base64UrlSafeNoPadding),
+
+            "base85" => Ok(Self::Base85Rfc1924),
+            "ascii85" => Ok(Self::Base85Ascii),
+
             _ => Err(format!("Unknown encoding: {}", s)),
         }
     }
@@ -173,22 +187,11 @@ mod tests {
     fn serde() {
         let t = |e: Encoding| assert_eq!(e, Encoding::from_str(&e.to_string()).unwrap());
 
-        // Test all long names
-        t(Encoding::Raw);
-        t(Encoding::ASCII);
-        t(Encoding::UTF8);
-        t(Encoding::Base32Crockford);
-        t(Encoding::Base32Rfc4648);
-        t(Encoding::Base32Rfc4648NoPadding);
-        t(Encoding::Base64Bcrypt);
-        t(Encoding::Base64Binhex);
-        t(Encoding::Base64Crypt);
-        t(Encoding::Base64ImapMutf7);
-        t(Encoding::Base64Standard);
-        t(Encoding::Base64StandardNoPadding);
-        t(Encoding::Base64UrlSafe);
-        t(Encoding::Base64UrlSafeNoPadding);
-        t(Encoding::Hex);
+        // Test all default names
+        use strum::IntoEnumIterator;
+        for enc in Encoding::iter() {
+            t(enc);
+        }
 
         // Test short names
         let t = |e: Encoding, s| assert_eq!(e, Encoding::from_str(s).unwrap());
